New class

Inheritance
Available extensions

Constructors

New({Key? key})
const

Properties

center Widget

Available on Widget, provided by the WidgetExtensions extension

Centers the widget.
no setter
expanded Widget

Available on Widget, provided by the WidgetExtensions extension

Wraps with Expanded.
no setter
fitted Widget

Available on Widget, provided by the WidgetExtensions extension

Wrap with FittedBox.
no setter
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeArea Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Add safe area wrapper.
no setter
scrollable Widget

Available on Widget, provided by the WidgetExtensions extension

Make widget scrollable (SingleChildScrollView).
no setter
scrollX Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Make widget scrollable horizontally.
no setter
scrollY Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Make widget scrollable vertically.
no setter

Methods

align(Alignment alignment) Widget

Available on Widget, provided by the WidgetExtensions extension

Wrap with Align.
aspect(double ratio) Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Add aspect ratio.
background(Color color) Widget

Available on Widget, provided by the WidgetExtensions extension

Adds background color.
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
clipRRect([double radius = 12]) Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Add ClipRRect with radius.
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expandedFlex(int flex) Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Wrap with Expanded and give flex.
fadeIn({Duration duration = const Duration(milliseconds: 300)}) Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Animate widget fade in.
flexible({int flex = 1, FlexFit fit = FlexFit.loose}) Widget

Available on Widget, provided by the WidgetExtensions extension

Wraps with Flexible.
hero(String tag) Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Add Hero animation.
inkTap(VoidCallback? onTap, {BorderRadius? radius}) Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Add InkWell with ripple effect.
marginAll(double value) Widget

Available on Widget, provided by the WidgetExtensions extension

Adds margin using Container.
marginOnly({double l = 0, double t = 0, double r = 0, double b = 0}) Widget

Available on Widget, provided by the WidgetExtensions extension

marginSym({double h = 0, double v = 0}) Widget

Available on Widget, provided by the WidgetExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTap(VoidCallback onTap) Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Wrap with GestureDetector (onTap).
opacity(double value) Widget

Available on Widget, provided by the WidgetExtensions extension

Wrap with Opacity.
paddingAll(double value) Widget

Available on Widget, provided by the WidgetExtensions extension

Adds padding on all sides.
paddingOnly({double l = 0, double t = 0, double r = 0, double b = 0}) Widget

Available on Widget, provided by the WidgetExtensions extension

Adds custom padding.
paddingSym({double h = 0, double v = 0}) Widget

Available on Widget, provided by the WidgetExtensions extension

Adds symmetric padding.
rotate(double angle) Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Add Rotation.
scale(double factor) Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Add Scale.
sized({double? w, double? h}) Widget

Available on Widget, provided by the WidgetExtensions extension

Wraps with SizedBox (fixed width/height).
toCard({Color? color, double? elevation, EdgeInsetsGeometry? margin, ShapeBorder? shape}) Widget

Available on Widget, provided by the WidgetExtensions extension

Wrap with Card.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
visible(bool isVisible, {Widget? replacement}) Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Wrap in Visibility.
withBorder({double width = 1, Color color = Colors.black, double radius = 0}) Widget

Available on Widget, provided by the WidgetExtensions extension

Adds border.
withBorderRadius({double radius = 8, Color color = Colors.transparent}) Widget

Available on Widget, provided by the WidgetExtensions extension

Adds rounded corners with background color.
withShadow({double elevation = 4, Color shadowColor = Colors.black26, BorderRadiusGeometry? borderRadius}) Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Add shadow using Material.
withTooltip(String message) Widget

Available on Widget, provided by the MoreWidgetExtensions extension

Wrap with Tooltip.

Operators

operator ==(Object other) bool
The equality operator.
inherited